import { ApolloQueryResult } from 'apollo-client';
import { FetchResult } from 'apollo-link';
import { Cart, Me, Order, ShippingMethod, CustomerSignInResult, Customer } from './GraphQL';
export interface CustomQuery {
    query: string;
    variables: any;
}
export interface BaseSearch {
    customQuery?: CustomQuery;
    limit?: number;
    offset?: number;
    sort?: string[];
}
export interface ProductSearch extends BaseSearch {
    catId?: string | string[];
    skus?: string[];
    slug?: string;
    id?: string;
    filters?: Record<string, Filter>;
}
export interface Filter {
    options: FilterOption[];
    type: string;
}
export interface FilterOption {
    label: string;
    value: string | number | boolean | [number, number] | [string, string];
    selected: boolean;
}
export interface CategorySearch extends BaseSearch {
    catId?: string;
    slug?: string;
}
export interface OrderSearch extends BaseSearch {
    id?: string;
}
export declare enum AttributeType {
    STRING = "StringAttribute",
    DATE = "DateAttribute",
    DATETIME = "DateTimeAttribute",
    TIME = "TimeAttribute",
    NUMBER = "NumberAttribute",
    ENUM = "EnumAttribute",
    LOCALIZED_ENUM = "LocalizedEnumAttribute",
    LOCALIZED_STRING = "LocalizedStringAttribute",
    MONEY = "MoneyAttribute",
    BOOLEAN = "BooleanAttribute"
}
export declare type QueryResponse<K extends string, V> = ApolloQueryResult<Record<K, V>>;
export declare type MutationResponse<K extends string, V> = FetchResult<Record<K, V>>;
export declare type ProfileResponse = QueryResponse<'me', Me>;
export declare type CartQueryResponse = QueryResponse<'cart', Cart>;
export declare type OrderQueryResponse = QueryResponse<'order', Order>;
export declare type CartMutationResponse = MutationResponse<'cart', Cart>;
export declare type CartResponse = CartQueryResponse | CartMutationResponse;
export declare type OrderMutationResponse = MutationResponse<'order', Order>;
export declare type OrderResponse = OrderQueryResponse | OrderMutationResponse;
export declare type ShippingMethodsResponse = QueryResponse<'shippingMethods', ShippingMethod>;
export declare type SignInResponse = QueryResponse<'user', CustomerSignInResult>;
export declare type ChangeMyPasswordResponse = QueryResponse<'user', Customer>;
